==> haskell-cryptohash-cryptoapi-0.1.4-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-cryptoapi
version:              0.1.4
visibility:           public
id:                   cryptohash-cryptoapi-0.1.4-7FnxS6KKdNVKjMgPIDNZNs
key:                  cryptohash-cryptoapi-0.1.4-7FnxS6KKdNVKjMgPIDNZNs
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis:             Crypto-api interfaces for cryptohash
description:          Crypto-api interfaces for cryptohash
category:             Cryptography
abi:                  936293b8ba62b01f6a9cd60a97d03b02
exposed:              True
exposed-modules:      Crypto.Hash.CryptoAPI
import-dirs:          /usr/lib/ghc-8.10.1/site-local/cryptohash-cryptoapi-0.1.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/cryptohash-cryptoapi-0.1.4

hs-libraries:         HScryptohash-cryptoapi-0.1.4-7FnxS6KKdNVKjMgPIDNZNs
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    cereal-0.5.8.1-HU1Om29vBJGHr3TJypdaoY
    crypto-api-0.13.3-KvLl9TAtYiP2nqbqSlpcaS
    cryptonite-0.26-JIZdcaiOiQ0E7oAZnbqxMe
    memory-0.15.0-EuehB4FMe9b5ts9dSjTFQ5
    tagged-0.8.6-6GC8EUw1ctH7ZAzzvpqZ7j

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-cryptoapi-0.1.4-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-cryptoapi
version:              0.1.4
visibility:           public
id:                   cryptohash-cryptoapi-0.1.4-iILhpSkrp5Bei2ugjGDsb
key:                  cryptohash-cryptoapi-0.1.4-iILhpSkrp5Bei2ugjGDsb
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis:             Crypto-api interfaces for cryptohash
description:          Crypto-api interfaces for cryptohash
category:             Cryptography
abi:                  d680cf61d866e63d21a40caab378673c
exposed:              True
exposed-modules:      Crypto.Hash.CryptoAPI
import-dirs:          /usr/lib/ghc-8.10.1/site-local/cryptohash-cryptoapi-0.1.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/cryptohash-cryptoapi-0.1.4

hs-libraries:         HScryptohash-cryptoapi-0.1.4-iILhpSkrp5Bei2ugjGDsb
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    cereal-0.5.8.1-HU1Om29vBJGHr3TJypdaoY
    crypto-api-0.13.3-KvLl9TAtYiP2nqbqSlpcaS
    cryptonite-0.27-KrgyisRA3hE36npKAVbN1W
    memory-0.15.0-EuehB4FMe9b5ts9dSjTFQ5
    tagged-0.8.6-6GC8EUw1ctH7ZAzzvpqZ7j

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
